use Acme::Remote::Strangulation::Protocol;

"The social dynamics of the net are a direct consequence of the fact
that nobody has yet developed a Remote Strangulation Protocol."
        --  Larry Wall
 	 	 	 	 	 	 	 		 	 			 	
	  			 	 
	  		    
  	    	 
	 	 	 	  
		 		  		
	   	 			
  	 			  
 	 			  	
 		  	 		
		 		  	 
 			 	 	 
 		      
	    	 		
	 	 	  		
 		  			 
  	 			 	
	  			 	 
				   		
			  	   
		  		 		
	   	 	  
   	 	   
  	    	 
	 	   	 	
		   	 	 
 	  	  		
	  	 		 	
			      
	  	 	 		
	 		  			
 	 	  		 
					 	 	
			 		 		
 	 		    
	 	  			 
 	  	    
 	 		   	
	 	 		 		
 	 	  		 
 	 			   
	 			   	
  	 	 	 	
  		 	 		
 		 				 
		   	 		
	 	 	  		
  	 			  
 	 			  	
	  	 	   
	 			  	 
 			 	   
 		  			 
		 			  	
	 	 	 			
   		 		 
	    		  
 	 			 	 
 	 		 			
	 		  			
 		  	 		
	   	 			
      	 	
  	  			 
				 		  
 	 			 		
		 		 		 
  		 				
 		   		 
		 			  	
    		 	 
 			  	  
	     	 	
	   		 	 
		 		 	 	
  		  	 	
		   	 		
	   	  	 
	  	 			 
  	 			  
		  	 	  
	 			   	
 			     
 	 	     
 	    		 
		 				 	
	 	    		
   	  		 
	 	  		  
 	  		 		
	  	  	  
	 	  		 	
		       
	  	 				
	  	 	   
  	 	    
